;; Copyright 2008, 2009, 2010 Kevin Ryde.

;; This file is part of tcd-format.
;;
;; tcd-format is free software; you can redistribute it and/or modify it
;; under the terms of the GNU General Public License as published by the
;; Free Software Foundation; either version 3, or (at your option) any later
;; version.
;;
;; tcd-format is distributed in the hope that it will be useful, but WITHOUT
;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
;; FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
;; more details.
;;
;; You should have received a copy of the GNU General Public License along
;; with tcd-format; see the file COPYING.  Failing that, go to
;; <http://www.gnu.org/licenses/>.


(progn
  (add-to-list 'load-path (expand-file-name ".."))
  (require 'tcd-format)
  )
(require 'poe)

(modify-coding-system-alist 'file "\\.tcd\\'" 'raw-text-unix)

(find-file "/usr/share/xtide/")
(find-file "/usr/share/xtide/harmonics-initial.tcd")
(find-file "/usr/share/xtide/harmonics.tcd")

;;-----------------------------------------------------------------------------

(defun my-err ()
  (interactive)
  (copy-file "/usr/share/doc/base-files/copyright" "/tmp/d-tcd-format-bad.tcd"
             t)
  (find-file "/tmp/d-tcd-format-bad.tcd")
  (format-decode-buffer 'tcd))
(my-err)

(defun my-ok ()
  (interactive)
  (find-file "/usr/share/xtide/harmonics-initial.tcd")
  )
(my-ok)

(progn
  (switch-to-buffer "xx")
  (insert-file-contents "/usr/share/xtide/harmonics-initial.tcd"))


(setq debug-on-error t)
(debug-on-entry 'find-file-noselect-1)
(cancel-debug-on-entry 'find-file-noselect-1)
(defadvice message (after my-message-check activate)
  "My debug."
  (if (string-match "File exists, but cannot be read" (ad-get-arg 0))
      (debug)))
(message "File exists, but cannot be read.")

;;-----------------
;; compile

(progn
  (add-to-list 'load-path (expand-file-name "../../el/devel"))
  (require 'my-byte-compile)
  (my-byte-compile))
(progn
  (add-to-list 'load-path (expand-file-name "../../el/devel"))
  (require 'my-byte-compile)
  (my-show-autoloads))


;;-----------------------------------------------------------------------------
;; switch-to-buffer

(tcd-format-switch-to-buffer-other-window (get-buffer-create "xxx"))


;;-----------------------------------------------------------------------------

(let ((elfile (expand-file-name "../tcd-format.el"))
      (tempfile "/tmp/x.el")
      (print-level nil))
  (require 'autoload)
  (find-file tempfile)
  (erase-buffer)
  (generate-file-autoloads elfile)
  (save-buffer)
  (byte-compile-file tempfile)
  (delete-file (concat tempfile "c"))
  (delete-file tempfile))


;;-----------------------------------------------------------------------------

;; check works with non-existent current directory
(progn
  (modify-coding-system-alist 'file "\\.tcd\\'" 'raw-text-unix)
  (with-temp-buffer
    (let ((tempbuf (current-buffer)))
      (insert-file-contents-literally "/usr/share/xtide/harmonics-initial.tcd")
      (setq buffer-file-coding-system 'raw-text-unix)
      (setq default-directory "/no/such/dir/")
      (setq buffer-file-name "/no/such/dir/foo.tcd")
      (format-decode-buffer 'tcd)

      (or (equal default-directory "/no/such/dir/")
          (error "oops, default-directory changed"))
      (set-buffer-modified-p nil))))
